# $Id$

use strict;
use warnings;

use Test::More tests => 21;
use File::Temp qw(tempdir);
use POSIX qw(strftime);

use_ok('ObsData');

ok(my $o = ObsData->new('testdata/obsdata-conftest', logfile => "testdata/obsdata.log"), "Can create object");

# Log level testing
ok(ObsData::loglevel(0) eq "DEBUG", "Can get loglevel");
ok(ObsData::loglevel(10) eq "?????", "Can get wrong loglevel");
ok($o->loglevel(0) eq "DEBUG", "Can get loglevel");
ok($o->loglevel(10) eq "?????", "Can get wrong loglevel");
ok($o->logging(0, "FOO%s", "FOO") eq "FOOFOO", "logging properly return the message");

ok($o->load, "can load repository");
ok($o->is_obs('ohp'), "Isobs works");
ok(!$o->is_obs('ozone'), "Isobs works");
ok($o->getvalue('ohp', 'description'), "can get value");
ok($o->config_mtime > 0, "Can get mtime of config file");
ok($o->config_mtime > 0, "Can get mtime a second time of config file");

ok(eq_set([ $o->list_obs ], [ 'ohp' ]), "Can list observatories");

ok($o->is_obs('ohp'), "check is an obs is defined");
ok(!$o->is_obs('NOohp'), "check is an obs is not defined");

{
my %datadir =  $o->list_obsdatadir('ohp');
ok($datadir{ozone} eq 'testdata/ohp/ozone', "Can get list of data directory");
}

ok(eq_set([ $o->list_typedatadir('ozone') ], [ 'testdata/ohp/ozone', 'testdata/ohp' ]) , 'Can list data directory');
ok(eq_set([ $o->get_datadir('ohp', 'ozone') ], [ 'testdata/ohp/ozone', 'testdata/ohp' ]) , 'Can retrive data directory');
ok(eq_set([ $o->list_datatype ], [ 'oxygene', 'ozone' ]), "can get data type");

ok(ref $o->get_sub_plugin('ozone', 'match_plugin') eq 'CODE', 'can get plugin code');

$o = undef; # Explicit destroy
